tests.models.input.types package — django_analyses 0.0.3 documentation

# tests.models.input.types package

## Submodules

## tests.models.input.types.test_boolean_input module

class `tests.models.input.types.test_boolean_input.` `BooleanInputTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `BooleanInput` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_get_type`()
  `test_none_value_if_required_raises_validation_error`()
  `test_string`()

## tests.models.input.types.test_file_input module

class `tests.models.input.types.test_file_input.` `FileInputTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `FileInput` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_get_type`()
  `test_none_value_if_required_raises_validation_error`()
  `test_string`()

## tests.models.input.types.test_float_input module

class `tests.models.input.types.test_float_input.` `FloatInputTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `FloatInput` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_get_type`()
  `test_none_value_if_required_raises_validation_error`()
  `test_string`()
  `test_validate_max_value_raises_validation_error`()
  `test_validate_min_value_raises_validation_error`()

## tests.models.input.types.test_integer_input module

class `tests.models.input.types.test_integer_input.` `IntegerInputTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `IntegerInput` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_get_type`()
  `test_none_value_if_required_raises_validation_error`()
  `test_string`()
  `test_validate_max_value_raises_validation_error`()
  `test_validate_min_value_raises_validation_error`()

## tests.models.input.types.test_list_input module

class `tests.models.input.types.test_list_input.` `ListInputTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `ListInput` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_get_type`()
  `test_max_length_raises_validation_error`()
  `test_min_length_raises_validation_error`()
  `test_non_list_values_raise_validation_error`()
  `test_none_value_if_required_raises_validation_error`()
  `test_string`()
  `test_wrong_type_elements_raise_validation_error`()

## tests.models.input.types.test_string_input module

class `tests.models.input.types.test_string_input.` `StringInputTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `StringInput` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_default_output_directory`()
  `test_fix_output_path_with_absolute_path_value`()
  `test_fix_output_path_with_empty_value_and_definition_default`()
  `test_fix_output_path_with_empty_value_and_no_definition_default`()
  `test_fix_output_path_with_non_absolute_path_value`()
  `test_get_type`()
  `test_invalid_choice_raises_validation_error`()
  `test_none_value_if_required_raises_validation_error`()
  `test_string`()
  `test_validate_max_length_raises_validation_error`()
  `test_validate_min_length_raises_validation_error`()

## Module contents